<div id="overview-container" class="row d-flex justify-content-between align-items-center">
    <div class="col-4">
        <div class="card text-white" id="progress-card">
            <div class="card-header text-center">Found / Scanned / Total</div>
            <div class="card-body text-center">
                <span id="scan-devices-alive"></span> / 
                <span id="scan-devices-scanned"></span> /
                <span id="scan-devices-total"></span>
            </div>
        </div>
    </div>
    <div class="col-4">
        <div class="card text-white overview-card" id="runtime-card">
            <div class="card-header text-center">Runtime</div>
            <div class="card-body text-center">
                <span id="scan-run-time"></span>s
            </div>
        </div>
    </div>
    <div class="col-4">
        <div class="card text-white overview-card" id="stage-card">
            <div class="card-header text-center">Stage</div>
            <div class="card-body text-center">
                <span id="scan-stage"></span>
            </div>
        </div>
    </div>
</div>
